@@ -25,14 +25,14 @@
 #define MYMONEYSTATEMENTREADER_H
 
 // ----------------------------------------------------------------------------
-// QT Headers
+// TQt Headers
 
 #include <tqobject.h>
 #include <tqstring.h>
 #include <tqstringlist.h>
 
 // ----------------------------------------------------------------------------
-// KDE Headers
+// TDE Headers
 
 #include <tdetempfile.h>
 #include <kprocess.h>
@@ -54,7 +54,7 @@ class TQStringList;
   */
 class MyMoneyStatementReader : public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
