@@ -28,7 +28,7 @@
   */
 
 class KBackupDlg : public kbackupdlgdecl  {
-	Q_OBJECT
+	TQ_OBJECT
   
 private:
   void readConfig(void);
