@@ -20,14 +20,14 @@
 #endif
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqtimer.h>
 #include <tqwidgetlist.h>
 #include <tqlabel.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdelocale.h>
 #include <tdemessagebox.h>
@@ -107,12 +107,12 @@ KEnterScheduleDlg::KEnterScheduleDlg(TQWidget *parent, const MyMoneySchedule& sc
   m_scheduleName->setText(d->m_schedule.name());
   m_type->setText(KMyMoneyUtils::scheduleTypeToString(d->m_schedule.type()));
 
-  connect(buttonHelp, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotShowHelp()));
-  connect(buttonIgnore, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotIgnore()));
-  connect(buttonSkip, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotSkip()));
+  connect(buttonHelp, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotShowHelp()));
+  connect(buttonIgnore, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotIgnore()));
+  connect(buttonSkip, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSkip()));
 
   // force the initial height to be as small as possible
-  TQTimer::singleShot(0, this, TQT_SLOT(slotSetupSize()));
+  TQTimer::singleShot(0, this, TQ_SLOT(slotSetupSize()));
 }
 
 KEnterScheduleDlg::~KEnterScheduleDlg()
@@ -210,16 +210,16 @@ TransactionEditor* KEnterScheduleDlg::startEdit(void)
   }
 
   if(editor) {
-    connect(editor, TQT_SIGNAL(transactionDataSufficient(bool)), buttonOk, TQT_SLOT(setEnabled(bool)));
-    connect(editor, TQT_SIGNAL(escapePressed()), buttonCancel, TQT_SLOT(animateClick()));
-    connect(editor, TQT_SIGNAL(returnPressed()), buttonOk, TQT_SLOT(animateClick()));
+    connect(editor, TQ_SIGNAL(transactionDataSufficient(bool)), buttonOk, TQ_SLOT(setEnabled(bool)));
+    connect(editor, TQ_SIGNAL(escapePressed()), buttonCancel, TQ_SLOT(animateClick()));
+    connect(editor, TQ_SIGNAL(returnPressed()), buttonOk, TQ_SLOT(animateClick()));
 
-    connect(MyMoneyFile::instance(), TQT_SIGNAL(dataChanged()), editor, TQT_SLOT(slotReloadEditWidgets()));
-    // connect(editor, TQT_SIGNAL(finishEdit(const KMyMoneyRegister::SelectedTransactions&)), this, TQT_SLOT(slotLeaveEditMode(const KMyMoneyRegister::SelectedTransactions&)));
-    connect(editor, TQT_SIGNAL(createPayee(const TQString&, TQString&)), kmymoney2, TQT_SLOT(slotPayeeNew(const TQString&, TQString&)));
-    connect(editor, TQT_SIGNAL(createCategory(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQT_SLOT(slotCategoryNew(MyMoneyAccount&, const MyMoneyAccount&)));
-    connect(editor, TQT_SIGNAL(createSecurity(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQT_SLOT(slotInvestmentNew(MyMoneyAccount&, const MyMoneyAccount&)));
-    connect(MyMoneyFile::instance(), TQT_SIGNAL(dataChanged()), editor, TQT_SLOT(slotReloadEditWidgets()));
+    connect(MyMoneyFile::instance(), TQ_SIGNAL(dataChanged()), editor, TQ_SLOT(slotReloadEditWidgets()));
+    // connect(editor, TQ_SIGNAL(finishEdit(const KMyMoneyRegister::SelectedTransactions&)), this, TQ_SLOT(slotLeaveEditMode(const KMyMoneyRegister::SelectedTransactions&)));
+    connect(editor, TQ_SIGNAL(createPayee(const TQString&, TQString&)), kmymoney2, TQ_SLOT(slotPayeeNew(const TQString&, TQString&)));
+    connect(editor, TQ_SIGNAL(createCategory(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQ_SLOT(slotCategoryNew(MyMoneyAccount&, const MyMoneyAccount&)));
+    connect(editor, TQ_SIGNAL(createSecurity(MyMoneyAccount&, const MyMoneyAccount&)), kmymoney2, TQ_SLOT(slotInvestmentNew(MyMoneyAccount&, const MyMoneyAccount&)));
+    connect(MyMoneyFile::instance(), TQ_SIGNAL(dataChanged()), editor, TQ_SLOT(slotReloadEditWidgets()));
 
     // create the widgets, place them in the parent and load them with data
     // setup tab order
@@ -308,7 +308,7 @@ bool KEnterScheduleDlg::focusNextPrevChild(bool next)
     }
 
     if(w != currentWidget
-    && ((w->focusPolicy() & TQ_TabFocus) == TQ_TabFocus)
+    && ((w->focusPolicy() & TQWidget::TabFocus) == TQWidget::TabFocus)
     && w->isVisible() && w->isEnabled()) {
       // tqDebug("Selecting '%s' as focus", w->className());
       w->setFocus();
