@@ -14,8 +14,12 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqlabel.h>
 #include <tqradiobutton.h>
@@ -25,7 +29,7 @@
 #include <tqlayout.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdeapplication.h>
 #include <tdeglobal.h>
@@ -64,7 +68,7 @@ KFindTransactionDlg::KFindTransactionDlg(TQWidget *parent, const char *name) :
   m_tabWidget->setTabEnabled(m_resultPage, false);
 
   // 'cause we don't have a separate setupTextPage
-  connect(m_textEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateSelections()));
+  connect(m_textEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateSelections()));
 
   setupAccountsPage();
   setupCategoriesPage();
@@ -93,24 +97,24 @@ KFindTransactionDlg::KFindTransactionDlg(TQWidget *parent, const char *name) :
   m_register->setupRegister(MyMoneyAccount(), cols);
   m_register->setSelectionMode(TQTable::Single);
 
-  connect(m_register, TQT_SIGNAL(editTransaction()), this, TQT_SLOT(slotSelectTransaction()));
-  connect(m_register, TQT_SIGNAL(headerClicked()), this, TQT_SLOT(slotSortOptions()));
+  connect(m_register, TQ_SIGNAL(editTransaction()), this, TQ_SLOT(slotSelectTransaction()));
+  connect(m_register, TQ_SIGNAL(headerClicked()), this, TQ_SLOT(slotSortOptions()));
 
   slotUpdateSelections();
 
   // setup the connections
-  connect(m_searchButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotSearch()));
-  connect(m_resetButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotReset()));
-  connect(m_resetButton, TQT_SIGNAL(clicked()), m_accountsView, TQT_SLOT(slotSelectAllAccounts()));
-  connect(m_resetButton, TQT_SIGNAL(clicked()), m_categoriesView, TQT_SLOT(slotSelectAllAccounts()));
-  connect(m_closeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(deleteLater()));
-  connect(m_helpButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotShowHelp()));
+  connect(m_searchButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSearch()));
+  connect(m_resetButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotReset()));
+  connect(m_resetButton, TQ_SIGNAL(clicked()), m_accountsView, TQ_SLOT(slotSelectAllAccounts()));
+  connect(m_resetButton, TQ_SIGNAL(clicked()), m_categoriesView, TQ_SLOT(slotSelectAllAccounts()));
+  connect(m_closeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(deleteLater()));
+  connect(m_helpButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotShowHelp()));
 
   // only allow searches when a selection has been made
-  connect(this, TQT_SIGNAL(selectionEmpty(bool)), m_searchButton, TQT_SLOT(setDisabled(bool)));
+  connect(this, TQ_SIGNAL(selectionEmpty(bool)), m_searchButton, TQ_SLOT(setDisabled(bool)));
 
   // get signal about engine changes
-  connect(MyMoneyFile::instance(), TQT_SIGNAL(dataChanged()), this, TQT_SLOT(slotRefreshView()));
+  connect(MyMoneyFile::instance(), TQ_SIGNAL(dataChanged()), this, TQ_SLOT(slotRefreshView()));
 
   slotUpdateSelections();
 
@@ -283,7 +287,7 @@ void KFindTransactionDlg::setupAccountsPage(void)
   //set the accountset to show closed account if the settings say so
   accountSet.setHideClosedAccounts(KMyMoneyGlobalSettings::hideClosedAccounts());
   accountSet.load(m_accountsView);
-  connect(m_accountsView, TQT_SIGNAL(stateChanged()), this, TQT_SLOT(slotUpdateSelections()));
+  connect(m_accountsView, TQ_SIGNAL(stateChanged()), this, TQ_SLOT(slotUpdateSelections()));
 }
 
 void KFindTransactionDlg::selectAllItems(TQListView* view, const bool state)
@@ -323,7 +327,7 @@ void KFindTransactionDlg::setupCategoriesPage(void)
   categorySet.addAccountGroup(MyMoneyAccount::Income);
   categorySet.addAccountGroup(MyMoneyAccount::Expense);
   categorySet.load(m_categoriesView);
-  connect(m_categoriesView, TQT_SIGNAL(stateChanged()), this, TQT_SLOT(slotUpdateSelections()));
+  connect(m_categoriesView, TQ_SIGNAL(stateChanged()), this, TQ_SLOT(slotUpdateSelections()));
 }
 
 void KFindTransactionDlg::selectAllSubItems(TQListViewItem* item, const bool state)
@@ -355,9 +359,9 @@ void KFindTransactionDlg::setupDatePage(void)
     MyMoneyTransactionFilter::translateDateRange(static_cast<MyMoneyTransactionFilter::dateOptionE>(i), m_startDates[i], m_endDates[i]);
   }
 
-  connect(m_dateRange, TQT_SIGNAL(itemSelected(int)), this, TQT_SLOT(slotDateRangeChanged(int)));
-  connect(m_fromDate, TQT_SIGNAL(dateChanged(const TQDate&)), this, TQT_SLOT(slotDateChanged()));
-  connect(m_toDate, TQT_SIGNAL(dateChanged(const TQDate&)), this, TQT_SLOT(slotDateChanged()));
+  connect(m_dateRange, TQ_SIGNAL(itemSelected(int)), this, TQ_SLOT(slotDateRangeChanged(int)));
+  connect(m_fromDate, TQ_SIGNAL(dateChanged(const TQDate&)), this, TQ_SLOT(slotDateChanged()));
+  connect(m_toDate, TQ_SIGNAL(dateChanged(const TQDate&)), this, TQ_SLOT(slotDateChanged()));
 
   slotDateRangeChanged(MyMoneyTransactionFilter::allDates);
 }
@@ -399,12 +403,12 @@ void KFindTransactionDlg::slotDateChanged(void)
 
 void KFindTransactionDlg::setupAmountPage(void)
 {
-  connect(m_amountButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotAmountSelected()));
-  connect(m_amountRangeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotAmountRangeSelected()));
+  connect(m_amountButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotAmountSelected()));
+  connect(m_amountRangeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotAmountRangeSelected()));
 
-  connect(m_amountEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateSelections()));
-  connect(m_amountFromEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateSelections()));
-  connect(m_amountToEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateSelections()));
+  connect(m_amountEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateSelections()));
+  connect(m_amountFromEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateSelections()));
+  connect(m_amountToEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateSelections()));
 
   m_amountButton->setChecked(true);
   slotAmountSelected();
@@ -434,9 +438,9 @@ void KFindTransactionDlg::setupPayeesPage(void)
   loadPayees();
   m_emptyPayeesButton->setChecked(false);
 
-  connect(m_allPayeesButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotSelectAllPayees()));
-  connect(m_clearPayeesButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotDeselectAllPayees()));
-  connect(m_emptyPayeesButton, TQT_SIGNAL(stateChanged(int)), this, TQT_SLOT(slotUpdateSelections()));
+  connect(m_allPayeesButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotSelectAllPayees()));
+  connect(m_clearPayeesButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotDeselectAllPayees()));
+  connect(m_emptyPayeesButton, TQ_SIGNAL(stateChanged(int)), this, TQ_SLOT(slotUpdateSelections()));
 }
 
 void KFindTransactionDlg::loadPayees(void)
@@ -449,7 +453,7 @@ void KFindTransactionDlg::loadPayees(void)
   // load view
   for(it_l = list.begin(); it_l != list.end(); ++it_l) {
     KMyMoneyCheckListItem* item = new KMyMoneyCheckListItem(m_payeesView, (*it_l).name(), TQString(), (*it_l).id());
-    connect(item, TQT_SIGNAL(stateChanged(bool)), this, TQT_SLOT(slotUpdateSelections()));
+    connect(item, TQ_SIGNAL(stateChanged(bool)), this, TQ_SLOT(slotUpdateSelections()));
     item->setOn(true);
   }
 }
@@ -465,15 +469,15 @@ void KFindTransactionDlg::slotDeselectAllPayees(void)
 
 void KFindTransactionDlg::setupDetailsPage(void)
 {
-  connect(m_typeBox, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotUpdateSelections()));
-  connect(m_stateBox, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotUpdateSelections()));
-  connect(m_validityBox, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotUpdateSelections()));
+  connect(m_typeBox, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotUpdateSelections()));
+  connect(m_stateBox, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotUpdateSelections()));
+  connect(m_validityBox, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotUpdateSelections()));
 
-  connect(m_nrButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotNrSelected()));
-  connect(m_nrRangeButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotNrRangeSelected()));
-  connect(m_nrEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateSelections()));
-  connect(m_nrFromEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateSelections()));
-  connect(m_nrToEdit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(slotUpdateSelections()));
+  connect(m_nrButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotNrSelected()));
+  connect(m_nrRangeButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotNrRangeSelected()));
+  connect(m_nrEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateSelections()));
+  connect(m_nrFromEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateSelections()));
+  connect(m_nrToEdit, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(slotUpdateSelections()));
 
   m_nrButton->setChecked(true);
   slotNrSelected();
@@ -722,7 +726,7 @@ void KFindTransactionDlg::loadView(void)
   m_tabWidget->setTabEnabled(m_resultPage, true);
   m_tabWidget->setCurrentPage(m_tabWidget->indexOf(m_resultPage));
 
-  TQTimer::singleShot(10, this, TQT_SLOT(slotRightSize()));
+  TQTimer::singleShot(10, this, TQ_SLOT(slotRightSize()));
 }
 
 void KFindTransactionDlg::slotRightSize(void)
@@ -792,7 +796,7 @@ bool KFindTransactionDlg::eventFilter(TQObject* o, TQEvent* e)
   if(o->isWidgetType()) {
     if(e->type() == TQEvent::KeyPress) {
       const TQWidget* w = dynamic_cast<const TQWidget*>(o);
-      TQKeyEvent *k = TQT_TQKEYEVENT (e);
+      TQKeyEvent *k = static_cast<TQKeyEvent*> (e);
       if(w == m_register) {
         switch(k->key()) {
           default:
@@ -835,9 +839,4 @@ void KFindTransactionDlg::slotSortOptions(void)
   }
   delete dlg;
 }
-
-
-// vim:cin:si:ai:et:ts=2:sw=2:
-
-
 #include "kfindtransactiondlg.moc"
