@@ -14,15 +14,19 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqlayout.h>
 #include <tqlabel.h>
 #include <tqwhatsthis.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdelocale.h>
 #include <keditlistbox.h>
@@ -63,9 +67,9 @@ KGpgKeySelectionDlg::KGpgKeySelectionDlg(TQWidget *parent, const char *name) :
 
   topLayout->addLayout(ledBox);
 
-  connect(m_listBox, TQT_SIGNAL(changed()), this, TQT_SLOT(slotIdChanged()));
-  connect(m_listBox, TQT_SIGNAL(added(const TQString&)), this, TQT_SLOT(slotKeyListChanged()));
-  connect(m_listBox, TQT_SIGNAL(removed(const TQString&)), this, TQT_SLOT(slotKeyListChanged()));
+  connect(m_listBox, TQ_SIGNAL(changed()), this, TQ_SLOT(slotIdChanged()));
+  connect(m_listBox, TQ_SIGNAL(added(const TQString&)), this, TQ_SLOT(slotKeyListChanged()));
+  connect(m_listBox, TQ_SIGNAL(removed(const TQString&)), this, TQ_SLOT(slotKeyListChanged()));
 }
 
 void KGpgKeySelectionDlg::setKeys(const TQStringList& list)
