@@ -15,8 +15,12 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqpushbutton.h>
 #include <tqlistbox.h>
@@ -25,9 +29,9 @@
 #include <tqtabwidget.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
-#include "kdecompat.h"
+#include <tdeversion.h>
 #include <tdelocale.h>
 #include <tdeglobal.h>
 #include <tdeconfig.h>
@@ -97,37 +101,37 @@ MyMoneyQifProfileEditor::MyMoneyQifProfileEditor(const bool edit, TQWidget *pare
                       i18n("Use this to create a new QIF import/export profile"));
   m_newButton->setGuiItem(newButtenItem);
 
-  connect(m_profileListBox, TQT_SIGNAL(highlighted(const TQString&)), this, TQT_SLOT(slotLoadProfileFromConfig(const TQString&)));
-  connect(m_resetButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotReset()));
-  connect(m_okButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotOk()));
-  connect(m_renameButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotRename()));
-  connect(m_deleteButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotDelete()));
-  connect(m_newButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotNew()));
-  connect(m_cancelButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(reject()));
-  connect(m_helpButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotHelp()));
+  connect(m_profileListBox, TQ_SIGNAL(highlighted(const TQString&)), this, TQ_SLOT(slotLoadProfileFromConfig(const TQString&)));
+  connect(m_resetButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotReset()));
+  connect(m_okButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotOk()));
+  connect(m_renameButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotRename()));
+  connect(m_deleteButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotDelete()));
+  connect(m_newButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotNew()));
+  connect(m_cancelButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(reject()));
+  connect(m_helpButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotHelp()));
 
-  connect(m_editDescription, TQT_SIGNAL(textChanged(const TQString&)), &m_profile, TQT_SLOT(setProfileDescription(const TQString&)));
-  connect(m_editType, TQT_SIGNAL(textChanged(const TQString&)), &m_profile, TQT_SLOT(setProfileType(const TQString&)));
-  connect(m_editOpeningBalance, TQT_SIGNAL(textChanged(const TQString&)), &m_profile, TQT_SLOT(setOpeningBalanceText(const TQString&)));
-  connect(m_editAccountDelimiter, TQT_SIGNAL(textChanged(const TQString&)), &m_profile, TQT_SLOT(setAccountDelimiter(const TQString&)));
-  connect(m_editVoidMark, TQT_SIGNAL(textChanged(const TQString&)), &m_profile, TQT_SLOT(setVoidMark(const TQString&)));
+  connect(m_editDescription, TQ_SIGNAL(textChanged(const TQString&)), &m_profile, TQ_SLOT(setProfileDescription(const TQString&)));
+  connect(m_editType, TQ_SIGNAL(textChanged(const TQString&)), &m_profile, TQ_SLOT(setProfileType(const TQString&)));
+  connect(m_editOpeningBalance, TQ_SIGNAL(textChanged(const TQString&)), &m_profile, TQ_SLOT(setOpeningBalanceText(const TQString&)));
+  connect(m_editAccountDelimiter, TQ_SIGNAL(textChanged(const TQString&)), &m_profile, TQ_SLOT(setAccountDelimiter(const TQString&)));
+  connect(m_editVoidMark, TQ_SIGNAL(textChanged(const TQString&)), &m_profile, TQ_SLOT(setVoidMark(const TQString&)));
 
-  //connect(m_editDateFormat, TQT_SIGNAL(highlighted(const TQString&)), &m_profile, TQT_SLOT(setDateFormat(const TQString&)));
-  connect(m_editApostrophe, TQT_SIGNAL(highlighted(const TQString&)), &m_profile, TQT_SLOT(setApostropheFormat(const TQString&)));
+  //connect(m_editDateFormat, TQ_SIGNAL(highlighted(const TQString&)), &m_profile, TQ_SLOT(setDateFormat(const TQString&)));
+  connect(m_editApostrophe, TQ_SIGNAL(highlighted(const TQString&)), &m_profile, TQ_SLOT(setApostropheFormat(const TQString&)));
 
-  connect(m_editAmounts, TQT_SIGNAL(selectionChanged(TQListViewItem*)), this, TQT_SLOT(slotAmountTypeSelected(TQListViewItem*)));
-  connect(m_decimalBox, TQT_SIGNAL(activated(const TQString&)), this, TQT_SLOT(slotDecimalChanged(const TQString&)));
-  connect(m_thousandsBox, TQT_SIGNAL(activated(const TQString&)), this, TQT_SLOT(slotThousandsChanged(const TQString&)));
+  connect(m_editAmounts, TQ_SIGNAL(selectionChanged(TQListViewItem*)), this, TQ_SLOT(slotAmountTypeSelected(TQListViewItem*)));
+  connect(m_decimalBox, TQ_SIGNAL(activated(const TQString&)), this, TQ_SLOT(slotDecimalChanged(const TQString&)));
+  connect(m_thousandsBox, TQ_SIGNAL(activated(const TQString&)), this, TQ_SLOT(slotThousandsChanged(const TQString&)));
 
-  connect(m_editInputFilterLocation, TQT_SIGNAL(textChanged(const TQString&)), &m_profile, TQT_SLOT(setFilterScriptImport(const TQString&)));
-  connect(m_editInputFilterLocation, TQT_SIGNAL(urlSelected(const TQString&)), m_editInputFilterLocation, TQT_SLOT(setURL(const TQString&)));
+  connect(m_editInputFilterLocation, TQ_SIGNAL(textChanged(const TQString&)), &m_profile, TQ_SLOT(setFilterScriptImport(const TQString&)));
+  connect(m_editInputFilterLocation, TQ_SIGNAL(urlSelected(const TQString&)), m_editInputFilterLocation, TQ_SLOT(setURL(const TQString&)));
 
-  connect(m_editInputFilterFileType, TQT_SIGNAL(textChanged(const TQString&)), &m_profile, TQT_SLOT(setFilterFileType(const TQString&)));
+  connect(m_editInputFilterFileType, TQ_SIGNAL(textChanged(const TQString&)), &m_profile, TQ_SLOT(setFilterFileType(const TQString&)));
 
-  connect(m_editOutputFilterLocation, TQT_SIGNAL(textChanged(const TQString&)), &m_profile, TQT_SLOT(setFilterScriptExport(const TQString&)));
-  connect(m_editOutputFilterLocation, TQT_SIGNAL(urlSelected(const TQString&)), m_editOutputFilterLocation, TQT_SLOT(setURL(const TQString&)));
+  connect(m_editOutputFilterLocation, TQ_SIGNAL(textChanged(const TQString&)), &m_profile, TQ_SLOT(setFilterScriptExport(const TQString&)));
+  connect(m_editOutputFilterLocation, TQ_SIGNAL(urlSelected(const TQString&)), m_editOutputFilterLocation, TQ_SLOT(setURL(const TQString&)));
 
-  connect(m_attemptMatch, TQT_SIGNAL(toggled(bool)), &m_profile, TQT_SLOT(setAttemptMatchDuplicates(bool)));
+  connect(m_attemptMatch, TQ_SIGNAL(toggled(bool)), &m_profile, TQ_SLOT(setAttemptMatchDuplicates(bool)));
 }
 
 MyMoneyQifProfileEditor::~MyMoneyQifProfileEditor()
@@ -398,7 +402,7 @@ void MyMoneyQifProfileEditor::slotNew(void)
 
 const TQString MyMoneyQifProfileEditor::enterName(bool& ok)
 {
-  MyMoneyQifProfileNameValidator val(TQT_TQOBJECT(this), "Validator");
+  MyMoneyQifProfileNameValidator val(this, "Validator");
 #if KDE_IS_VERSION(3,2,0)
   return KInputDialog::getText(i18n("QIF Profile Editor"),
                                i18n("Enter new profile name"),
