@@ -362,13 +362,13 @@ bool MyMoneyTransaction::isStockSplit(void) const
 
 bool MyMoneyTransaction::isImported(void) const
 {
-  return value("Imported").lower() == TQString("true");
+  return value("Imported").lower() == TQString("TRUE");
 }
 
 void MyMoneyTransaction::setImported(bool state)
 {
   if(state)
-    setValue("Imported", "true");
+    setValue("Imported", "TRUE");
   else
     deletePair("Imported");
 }
