@@ -18,17 +18,13 @@
 #ifndef STATEMENTINTERFACE_H
 #define STATEMENTINTERFACE_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqobject.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -44,7 +40,7 @@ namespace KMyMoneyPlugin {
   * into the KMyMoney application
   */
 class KMYMONEY_EXPORT StatementInterface : public TQObject {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
