@@ -174,7 +174,7 @@ kMyMoneyCalendar::eventFilter(TQObject *o, TQEvent *e )
        {
           TQApplication::sendEvent( table, e );
           table->setFocus();
-          return TRUE; // eat event
+          return true; // eat event
        }
    }
    return TQFrame::eventFilter( o, e );
