@@ -48,12 +48,12 @@
 #define KMYMONEYCALENDAR_H
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 #include <tqframe.h>
 #include <tqdatetime.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <tdeversion.h>
 
@@ -74,7 +74,7 @@ class TQPushButton;
   *
 **/
 class kMyMoneyCalendar : public TQFrame  {
-   Q_OBJECT
+   TQ_OBJECT
   
 public:
 
